@@ -21,8 +21,8 @@
 #' @examples
 #' \dontrun{
 #' library(dplyr)
-#' df <- chickwts %>%
-#' mutate(across(where(is.character), as.factor)) %>%
+#' df <- chickwts |>
+#' mutate(across(where(is.character), as.factor)) |>
 #' mutate(across(where(is.factor), ~biggest_reference(., weight)))
 #' }
 #'
@@ -135,10 +135,6 @@ get_splits <- function(x) {
 ggplot2::autoplot
 
 
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
 
 #' @keywords internal
 order_factors_exposure <- function(x, weight, decreasing) {
